############ R code Remote Sensing special issue

library(tm)
library(wordcloud)
library(RColorBrewer)
library(Matrix)
# Set of abstracts of the Special Issue
abstracts <- read.csv("abstracts.csv", na.strings="NA", sep=";", header=F)

# Building the Term Document Matrix step by step: overwriting
abstracts_new <- Corpus(DataframeSource(data.frame(as.character(abstracts[,1]))))
abstracts_new <- tm_map(abstracts_new, removePunctuation)
abstracts_new <- tm_map(abstracts_new, content_transformer(tolower))
my_stopwords <- c(stopwords('english'),"of")
abstracts_new <- tm_map(abstracts_new, removeWords, my_stopwords)

abstracts_new.tdm <- TermDocumentMatrix(abstracts_new)

ab.m <- as.matrix(abstracts_new.tdm) 
ab.v <- sort(rowSums(ab.m),decreasing=TRUE) # frequencies
ab.d <- data.frame(word = names(ab.v),freq=ab.v)
table(ab.d$freq)
pal_dark <- brewer.pal(8,"Dark2")

png("abstracts_cloud3.png")
wordcloud(ab.d$word,ab.d$freq, scale=c(8,.2),min.freq=2,
max.words=Inf, random.order=FALSE, rot.per=.15, colors=pal_dark)
dev.off()
system("gwenview abstracts_cloud.png")

################## references


library(tm)
library(wordcloud)
library(RColorBrewer)
library(Matrix)
# Set of references cited in the papers of the Special Issue
references <- read.csv("references.csv", na.strings="NA", sep=";", header=F)

# Building the Term Document Matrix step by step: overwriting
references_new <- Corpus(DataframeSource(data.frame(as.character(references[,1]))))
references_new <- tm_map(references_new, removePunctuation)
references_new <- tm_map(references_new, content_transformer(tolower))
my_stopwords <- c(stopwords('english'),"of", "google", "scholar", "googlescholar", "google scholar", "crossref", "sens", "environ")
references_new <- tm_map(references_new, removeWords, my_stopwords)

references_new.tdm <- TermDocumentMatrix(references_new)

ref.m <- as.matrix(references_new.tdm) 
ref.v <- sort(rowSums(ref.m),decreasing=TRUE) # frequencies
ref.d <- data.frame(word = names(ref.v),freq=ref.v)
table(ref.d$freq)
pal_dark <- brewer.pal(8,"Dark2")

png("reference_cloud.png")
wordcloud(ref.d$word,ref.d$freq, scale=c(8,.2),min.freq=2,
max.words=Inf, random.order=FALSE, rot.per=.15, colors=pal_dark)
dev.off()
system("gwenview reference_cloud.png")




